@@ -29,12 +29,13 @@ struct _VoiceWindow {
 };
 
 struct _LocationInfo {
-	gfloat *lat;
-	gfloat *lon;
+	float lat;
+	float lon;
 	gchar *city;
 };
 
 struct _VoiceInfo {
+        gchar *name;
 	gchar *uri;
 	LocationInfo *location;
 	StreamInfo *stream;
@@ -48,4 +49,6 @@ struct _StreamInfo {
 	StreamInfo *prev;	
 };
 
+VoiceInfo *gnome_voice_file_loader (VoiceInfo *head, char *filename);
+
 #endif /* GNOME_VOICE_FILE_H */
