@@ -599,6 +599,13 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	fprintf(voice_pointer, "</voice>\n");
 	fclose(voice_pointer);
 	g_date_time_unref (datestamp);
+        if (!main_loops) {
+                g_error("Quit more loops than there are.");
+        } else {
+                GMainLoop *loop = main_loops;
+                g_main_loop_quit(loop);
+                gtk_main_quit();
+        }
 	// gst_element_send_event(data, gst_event_new_eos());
 }
 
@@ -652,7 +659,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 1.0.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 1.0.1", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Title", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -673,7 +680,7 @@ main (gint argc, gchar **argv)
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 1.0.0");
+	context = g_option_context_new ("- Voice 1.0.1");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -686,10 +693,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.0.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.0.1");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 1.0.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 1.0.1!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Title:"));
 	title_entry = gtk_entry_new();
@@ -767,7 +774,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 1.0.0",
+				 GST_TAG_COMMENT, "Voice 1.0.1",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
